@@ -43,7 +43,7 @@ JuliaServer::~JuliaServer()
 
 void JuliaServer::login(const QString &path) const
 {
-#if JULIA_VERSION_MINOR > 5
+#if QT_VERSION_CHECK(JULIA_VERSION_MAJOR, JULIA_VERSION_MINOR, 0) >= QT_VERSION_CHECK(0, 6, 0)
     Q_UNUSED(path)
     jl_init();
 #else
@@ -52,6 +52,13 @@ void JuliaServer::login(const QString &path) const
 #endif
 }
 
+#if QT_VERSION_CHECK(JULIA_VERSION_MAJOR, JULIA_VERSION_MINOR, 0) >= QT_VERSION_CHECK(0, 7, 0)
+#define JULIA_STDOUT "stdout"
+#define JULIA_STDERR "stderr"
+#else
+#define JULIA_STDOUT "STDOUT"
+#define JULIA_STDERR "STDOUT"
+#endif
 void JuliaServer::runJuliaCommand(const QString &command)
 {
     // Redirect stdout, stderr to temprorary files
@@ -60,8 +67,8 @@ void JuliaServer::runJuliaCommand(const QString &command)
         qFatal("Unable to create temporary files for stdout/stderr");
         return;
     }
-    jl_eval_string("const __originalSTDOUT__ = STDOUT");
-    jl_eval_string("const __originalSTDERR__ = STDERR");
+    jl_eval_string("const __originalSTDOUT__ = " JULIA_STDOUT);
+    jl_eval_string("const __originalSTDERR__ = " JULIA_STDERR);
     jl_eval_string(
         QString::fromLatin1("redirect_stdout(open(\"%1\", \"w\"))")
             .arg(output.fileName()).toLatin1().constData()
@@ -86,7 +93,7 @@ void JuliaServer::runJuliaCommand(const QString &command)
             jl_eval_string("catch_backtrace()")
         );
         jl_value_t *err_stream = static_cast<jl_value_t *>(
-            jl_eval_string("STDERR")
+            jl_eval_string(JULIA_STDERR)
         );
         jl_call3(showerror, err_stream, ex, bt);
         jl_exception_clear();
@@ -100,15 +107,15 @@ void JuliaServer::runJuliaCommand(const QString &command)
             static_cast<jl_value_t *>(jl_call2(equality, nothing, val))
         );
         if (!is_nothing) {
-            jl_value_t *out_display = static_cast<jl_value_t *>(jl_eval_string("TextDisplay(STDOUT)"));
+            jl_value_t *out_display = static_cast<jl_value_t *>(jl_eval_string("TextDisplay(" JULIA_STDOUT ")"));
             jl_function_t *display = jl_get_function(jl_base_module, "display");
             jl_call2(display, out_display, val);
         }
         m_was_exception = false;
     }
     // Clean up streams and files
-    jl_eval_string("flush(STDOUT)");
-    jl_eval_string("flush(STDERR)");
+    jl_eval_string("flush(" JULIA_STDOUT ")");
+    jl_eval_string("flush(" JULIA_STDERR ")");
     jl_eval_string("redirect_stdout(__originalSTDOUT__)");
     jl_eval_string("redirect_stderr(__originalSTDERR__)");
 
@@ -209,11 +216,7 @@ void JuliaServer::parseJlModule(jl_module_t* module)
 
 QString JuliaServer::fromJuliaString(const jl_value_t* value)
 {
-#if JULIA_VERSION_MINOR > 5
-        return QString::fromUtf8(jl_string_ptr(value));
-#else
-        return QString::fromUtf8(jl_string_data(value));
-#endif 
+    return QString::fromUtf8(jl_string_data(value));
 }
 
 QStringList JuliaServer::variablesList()
